ModulatorySignal
================

.. _ModulatorySignal_Subtypes:

.. container:: subclasses
    *Subclasses*

    .. toctree::
       :maxdepth: 1

       LearningSignal
       ControlSignal
       GatingSignal

    .. toctree::
       :maxdepth: 3

.. automodule:: psyneulink.core.components.ports.modulatorysignals.modulatorysignal
   :members:
   :private-members:
   :exclude-members: random, update, Parameters

